@@ -72,7 +72,7 @@ class LambdaToSqsToLambda(
         '''
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
-        :param consumer_lambda_function_props: Optional - user provided props to override the default props for the consumer Lambda function. Providing both this and ``existingConsumerLambdaObj`` is an error. Default: - Default properties are used.
+        :param consumer_lambda_function_props: Optional - user provided props to override the default props for the consumer Lambda function. Providing both this and ``existingConsumerLambdaObj`` causes an error. Default: - Default properties are used.
         :param dead_letter_queue_props: Optional user-provided props to override the default props for the dead letter queue. Only used if the ``deployDeadLetterQueue`` property is set to true. Default: - Default props are used.
         :param deploy_dead_letter_queue: Whether to create a secondary queue to be used as a dead letter queue. Defaults to ``true``. Default: - true.
         :param deploy_vpc: Whether to deploy a new VPC. Default: - false
@@ -81,7 +81,7 @@ class LambdaToSqsToLambda(
         :param existing_queue_obj: An optional, existing SQS queue to be used instead of the default queue. Providing both this and ``queueProps`` will cause an error. Default: - None.
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         :param max_receive_count: The number of times a message can be unsuccessfully dequeued before being moved to the dead letter queue. Defaults to ``15``. Default: - 15.
-        :param producer_lambda_function_props: Optional - user provided props to override the default props for the producer Lambda function. Providing both this and ``existingProducerLambdaObj`` is an error. Default: - Default properties are used.
+        :param producer_lambda_function_props: Optional - user provided props to override the default props for the producer Lambda function. Providing both this and ``existingProducerLambdaObj`` causes an error. Default: - Default properties are used.
         :param queue_environment_variable_name: Optional Name for the Lambda function environment variable set to the URL of the queue. Default: - SQS_QUEUE_URL
         :param queue_props: Optional - user provided properties to override the default properties for the SQS queue. Providing both this and ``existingQueueObj`` will cause an error. Default: - Default props are used.
         :param sqs_event_source_props: Optional user provided properties for the queue event source. Default: - Default props are used
@@ -181,7 +181,7 @@ class LambdaToSqsToLambdaProps:
         vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
-        :param consumer_lambda_function_props: Optional - user provided props to override the default props for the consumer Lambda function. Providing both this and ``existingConsumerLambdaObj`` is an error. Default: - Default properties are used.
+        :param consumer_lambda_function_props: Optional - user provided props to override the default props for the consumer Lambda function. Providing both this and ``existingConsumerLambdaObj`` causes an error. Default: - Default properties are used.
         :param dead_letter_queue_props: Optional user-provided props to override the default props for the dead letter queue. Only used if the ``deployDeadLetterQueue`` property is set to true. Default: - Default props are used.
         :param deploy_dead_letter_queue: Whether to create a secondary queue to be used as a dead letter queue. Defaults to ``true``. Default: - true.
         :param deploy_vpc: Whether to deploy a new VPC. Default: - false
@@ -190,7 +190,7 @@ class LambdaToSqsToLambdaProps:
         :param existing_queue_obj: An optional, existing SQS queue to be used instead of the default queue. Providing both this and ``queueProps`` will cause an error. Default: - None.
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         :param max_receive_count: The number of times a message can be unsuccessfully dequeued before being moved to the dead letter queue. Defaults to ``15``. Default: - 15.
-        :param producer_lambda_function_props: Optional - user provided props to override the default props for the producer Lambda function. Providing both this and ``existingProducerLambdaObj`` is an error. Default: - Default properties are used.
+        :param producer_lambda_function_props: Optional - user provided props to override the default props for the producer Lambda function. Providing both this and ``existingProducerLambdaObj`` causes an error. Default: - Default properties are used.
         :param queue_environment_variable_name: Optional Name for the Lambda function environment variable set to the URL of the queue. Default: - SQS_QUEUE_URL
         :param queue_props: Optional - user provided properties to override the default properties for the SQS queue. Providing both this and ``existingQueueObj`` will cause an error. Default: - Default props are used.
         :param sqs_event_source_props: Optional user provided properties for the queue event source. Default: - Default props are used
@@ -262,7 +262,7 @@ class LambdaToSqsToLambdaProps:
     ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps]:
         '''Optional - user provided props to override the default props for the consumer Lambda function.
 
-        Providing both this and ``existingConsumerLambdaObj`` is an error.
+        Providing both this and ``existingConsumerLambdaObj`` causes an error.
 
         :default: - Default properties are used.
         '''
@@ -368,7 +368,7 @@ class LambdaToSqsToLambdaProps:
         '''Optional - user provided props to override the default props for the producer Lambda function.
 
         Providing
-        both this and ``existingProducerLambdaObj`` is an error.
+        both this and ``existingProducerLambdaObj`` causes an error.
 
         :default: - Default properties are used.
         '''
